%define oname   The-Powder-Toy

# Comment/undefine snapshot to use the stable release.
#define snapshot 377

%define tar_tag  %{!?snapshot:%{version}}%{?snapshot:snapshot-%{snapshot}}

Name:           powdertoy
Version:        99.1.%{!?snapshot:380}%{?snapshot:%snapshot}
Release:        %mkrel 1
Summary:        Falling-sand physics sandbox game
Group:          Games/Simulation
License:        GPLv3+
Url:            https://powdertoy.co.uk/
Source0:        https://github.com/simtr/The-Powder-Toy/archive/%{!?snapshot:v%{version}}%{?snapshot:snapshot-%{snapshot}}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  desktop-file-utils

%description
The Powder Toy is a free physics sandbox game, which simulates
air pressure and velocity, heat, gravity and a countless number
of interactions between different substances! The game provides
you with various building materials, liquids, gases and electronic
components which can be used to construct complex machines, guns,
bombs, realistic terrains and almost anything else.

%prep
%autosetup -p1 -n %{oname}-%{tar_tag}

%build
%meson \
	--bindir=%{_gamesbindir} \
	-Dapp_data=%{name} \
	-Dapp_exe=%{name} \
	-Dapp_comment="Falling-sand physics sandbox game" \
	-Dcan_install=no \
	-Dlua=luajit \
%ifnarch x86_64
	-Dx86_sse=none \
%endif
	%nil
%meson_build

%install
%meson_install

%define app_mime  application-vnd.%{name}.save
# Default app_id: "powdertoy-uk.co.powdertoy.tpt"
%define app_id %{name}-$(grep '<id>' build/resources/appdata.xml | sed 's|.*<id>||;s|<\/id.*||')

# Icons
pushd resources/generated_icons
  install -D -m644 icon_exe_16.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
  install -D -m644 icon_exe_32.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
  install -D -m644 icon_exe_48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
  install -D -m644 icon_exe.png    %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
  install -D -m644 ../icon_exe.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

  install -D -m644 icon_cps_16.png %{buildroot}%{_iconsdir}/hicolor/16x16/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps_32.png %{buildroot}%{_iconsdir}/hicolor/32x32/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps_48.png %{buildroot}%{_iconsdir}/hicolor/48x48/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps.png    %{buildroot}%{_iconsdir}/hicolor/256x256/mimetypes/%{app_mime}.png
  install -D -m644 ../icon_cps.svg %{buildroot}%{_iconsdir}/hicolor/scalable/mimetypes/%{app_mime}.svg
popd

# Mimetypes, manpages, metainfo and desktop files
install -D -m644 resources/save.xml %{buildroot}%{_datadir}/mime/application/vnd.%{name}.save.xml
install -D -m644 resources/powder.man %{buildroot}%{_mandir}/man6/%{name}.6
install -D -m644 build/resources/appdata.xml %{buildroot}%{_metainfodir}/%{app_id}.appdata.xml
install -D -m644 build/resources/powder.desktop %{buildroot}%{_datadir}/applications/%{app_id}.desktop
desktop-file-install %{buildroot}%{_datadir}/applications/%{app_id}.desktop \
  --set-icon=%{name} --set-generic-name="Physics sandbox" \
  --set-key=Terminal --set-value=false

%files
%doc README.md
%license LICENSE
%{_gamesbindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/mime/application/vnd.%{name}.save.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/*/mimetypes/%{app_mime}.png
%{_iconsdir}/hicolor/scalable/mimetypes/%{app_mime}.svg
%{_metainfodir}/*.appdata.xml
%{_mandir}/man6/%{name}.6*


%changelog
* Sun Jan 26 2025 daviddavid <daviddavid> 99.1.380-1.mga10
+ Revision: 2142468
- new version: 99.1.380

* Wed Jan 08 2025 daviddavid <daviddavid> 99.0.377-1.mga10
+ Revision: 2136157
- new version: 99.0.377

* Fri Nov 08 2024 daviddavid <daviddavid> 98.2.372-2.mga10
+ Revision: 2113002
- do not own hicolor directory

* Fri Nov 08 2024 daviddavid <daviddavid> 98.2.372-1.mga10
+ Revision: 2113001
- new version: 98.2.372 (thanks to Aurelian R, mga#33734)

* Mon Nov 07 2022 ghibo <ghibo> 96.2.350-1.mga9
+ Revision: 1904519
- Fix meson x86_sse argument
- Update to release 96.2.350.
- Switch to meson and fix BRs.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Feb 27 2020 daviddavid <daviddavid> 95.0-1.mga8
+ Revision: 1550975
- new version: 95.0
- switch to luajit

* Sat Feb 15 2020 umeabot <umeabot> 94.1-2.mga8
+ Revision: 1525373
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Apr 14 2019 daviddavid <daviddavid> 94.1-1.mga7
+ Revision: 1389918
- new version: 94.1
- switch to sdl2

* Sun Sep 23 2018 umeabot <umeabot> 93.3-2.mga7
+ Revision: 1300355
- Mageia 7 Mass Rebuild

* Mon May 14 2018 akien <akien> 93.3-1.mga7
+ Revision: 1229454
- Version 93.3
- Version 92.5

* Mon Oct 02 2017 daviddavid <daviddavid> 92.1.332-2.mga7
+ Revision: 1162467
- patch1: fix build with scons 3.0

* Sat Aug 26 2017 akien <akien> 92.1.332-1.mga7
+ Revision: 1148041
- Version 92.1.332

* Sat Aug 13 2016 akien <akien> 91.5.330-1.mga6
+ Revision: 1046149
- Version 91.5.330

* Sun Apr 24 2016 akien <akien> 91.3.328-1.mga6
+ Revision: 1005860
- Version 91.3.328

* Thu Dec 24 2015 pterjan <pterjan> 90.2.322-4.mga6
+ Revision: 914036
- On i586 the binary gets renamed -legacy when sse is disabled...
- Only enable SSE/SSE2 for x86_64, arm really doesn't like it

* Thu Dec 24 2015 daviddavid <daviddavid> 90.2.322-2.mga6
+ Revision: 914008
- compile with debug symbols adding --debugging scons option

* Mon Jan 26 2015 akien <akien> 90.2.322-1.mga5
+ Revision: 812353
- imported package powdertoy

